.. inmydata documentation master file, created by
   sphinx-quickstart on Sun Jun 22 10:22:28 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

inmydata agents API reference
=============================

The inmydata agents Python Library enables you to build AI agents that can rapidly access data from the inmydata platform. 
Documentation, quickstarts, and examples `can be found here <https://developer.inmydata.com>`__

To install::

    pip install inmydata

.. toctree::
   :maxdepth: 2
   :caption: Classes:

   AIDataFilter
   AIDataSimpleFilter
   AIQuestionOutputTypeEnum
   AITypeEnum
   Answer
   CalendarAssistant
   ConditionOperator
   ConversationalDataDriver
   FinancialPeriodDetails
   LogicalOperator
   Model
   QuestionResponse
   StructuredDataDriver

